aboutsummaryrefslogtreecommitdiff
path: root/libbuild2/adhoc-rule-buildscript.cxx
diff options
context:
space:
mode:
Diffstat (limited to 'libbuild2/adhoc-rule-buildscript.cxx')
-rw-r--r--libbuild2/adhoc-rule-buildscript.cxx5
1 files changed, 3 insertions, 2 deletions
diff --git a/libbuild2/adhoc-rule-buildscript.cxx b/libbuild2/adhoc-rule-buildscript.cxx
index 25ef1b7..d91be65 100644
--- a/libbuild2/adhoc-rule-buildscript.cxx
+++ b/libbuild2/adhoc-rule-buildscript.cxx
@@ -459,10 +459,11 @@ namespace build2
// Note that we ignore the result and whether it renders us out of date,
// leaving it to the common execute logic in perform_update_*().
//
// Note also that update_during_match() spoils prerequisite_target::data.
//
if (a == perform_update_id)
- update_during_match (trace, a, pts, 2 /* mask */);
+ update_during_match_prerequisites (trace, a, xt, 2 /* mask */);
// See if this is not update or not on a file-based target.
//
@@ -459,10 +459,11 @@ namespace build2
// leaving it to the common execute logic in perform_update_*().
//
- // Note also that update_during_match() spoils prerequisite_target::data.
+ // Note also that update_during_match_prerequisites() spoils
+ // prerequisite_target::data.
//
if (a == perform_update_id)